.. _combinatorics-permutations:

Permutations
============

.. module:: sympy.combinatorics.permutations

.. autoclass:: Permutation
   :members:

.. autoclass:: Cycle
   :members:

.. autofunction:: _af_parity

.. _combinatorics-generators:

Generators
----------

.. module:: sympy.combinatorics.generators

.. automethod:: sympy.combinatorics.generators.symmetric

.. automethod:: sympy.combinatorics.generators.cyclic

.. automethod:: sympy.combinatorics.generators.alternating

.. automethod:: sympy.combinatorics.generators.dihedral
